package Acme::Travigator;

use warnings;
use strict;

sub travigate {
    return "I am not sure where you want to go\n";
}

1;

# ABSTRACT: who needs google when you have the travigator

=head1 SYNOPSIS

Acme::Travigator - A new way for finding directions

=method travigate

return directions to a random location
